BFGraph: minHashIterator< HF > Class Template Reference

BFGraph

Public Member Functions | Data Fields
minHashIterator< HF > Class Template Reference

## Public Member Functions
| minHashIterator (int _k, int _g, HF _h)
| minHashIterator (const char *_s, int _length, int _k, int _g, HF _h, bool _nh)
void | seed (HF &ohf)
void | initString (const char *_s, int _length)
bool | operator== (const minHashIterator &o)
bool | operator!= (const minHashIterator &o)
minHashIterator & | operator++ ()
minHashIterator | operator++ (int)
minHashIterator & | operator+= (int i)
minHashResult | getNewMin (const minHashResult &mhr_discard) const
minHashResultIterator< HF > | operator* () const
uint64_t | getHash () const
int | getPosition () const
int | getKmerPosition () const
| minHashIterator (const minHashIterator &o)

## Data Fields
const char * | s
int | n
int | k
int | g
HF | hf
deque< minHashResult > | v
int | p
bool | invalid
bool | nh

The documentation for this class was generated from the following file:

- src/minHashIterator.hpp